close all; % close all open figures

% set switch to print (i.e. save) figures or not
printFigs = false;

% create figure directory if needed
if  printFigs
    figDir = fullfile('.', 'figures');
    if ~exist(figDir,'dir'), mkdir(figDir); end
    chlDir = fullfile(figDir, 'animation_chl');
    if ~exist(chlDir,'dir'), mkdir(chlDir); end
end

%% load data
load SeaWiFS_chl_NewEngland

%% Animation of data fields: Note the missing values which would cause trouble for EOF analysis.
%  We need to exclude them.
figure(1)
for t=1:size(chl,1)
    pcolor(lon,lat,squeeze(chl(t,:,:)))
    colormap(cmocean('algae',20))
    shading interp
    plotnewengland
    caxis([0 5])
    colorbar
    title(date_str{t})
    pause(0.2)
    
    if  printFigs
        print(gcf, fullfile(chlDir, sprintf('chl_seawifs_%03d',t)), '-dpng', '-r300')
    end
end

%% look at all cloudy pixels
test_clouds = sum(chl,1);
figure(2);
pcolor(lon,lat,squeeze(test_clouds))
colormap(parula(20))
shading interp
plotnewengland
title('show cloudy pixels')

if  printFigs
    print(gcf, fullfile(figDir, 'cloudy_pixels'), '-dpng', '-r300')
end

%% EOF analysis:
% 1) transform 3D chl array into 2D data matrix and remove NaNs
% 1.1) determine land and cloud points (NaNs)
good_ind = ~isnan(test_clouds(:));
% 1.2) create 2D data matrix without NaNs
chl2D = nan(size(chl,1),sum(good_ind));
for t=1:size(chl,1)
    x = chl(t,:);
    chl2D(t,:) = x(good_ind);
end
% 1.3) dimensions of our data matrix are:
[M, N] = size(chl2D);

% 2) calculate anomalies
chl2D_mn = mean(chl2D,1); % means along time dimension
chl2D_an = chl2D - ones(M,1)*chl2D_mn; % anomalies

% 3) calculate eigenvalues and eigenvectors of cov-mat
% 3.1) calculate covariance matrix
C = chl2D_an'*chl2D_an/(M-1);
% 3.2) calculate SVD (and take the time)
tic
[U,S,V] = svd(C,0);
toc
disp('(for SVD only)')

% for comparison, take time for simple math on matrix of same size as C
time_ex_var = 10*ones(size(C));
tic
time_ex_var = time_ex_var.^2 + 4;
toc
disp('(for basic math)')

%% 4) look at the first 4 EOFs, variance explained and scores
% 4.1) turn back into 2D matrices and plot EOFs
aux = NaN(size(chl,2)*size(chl,3),1);
EOF = cell(1,4);
figure(3);
cLim = [0.08, 0.08, 0.08, 0.08];
for i=1:4
    aux(good_ind) = V(:,i);
    EOF{i} = reshape(aux,size(chl,2),size(chl,3));
    % plot EOF
    subplot(2,2,i)
    pcolor(lon,lat,EOF{i})
    shading interp
    colormap(cmocean('balance',20))
    caxis([-cLim(i),cLim(i)])
    plotnewengland, colorbar
    title(['EOF ' num2str(i)])
end
set(3, 'Position', [100, 100, 1000, 800])

if  printFigs
    print(gcf, fullfile(figDir, 'EOFs_chl_NewEngland'), '-dpng', '-r300')
end

%% 4.2) look at variance explained
var_explained = diag(S)/trace(S);
figure(4);
plot(var_explained(1:10)*100, 'o-', 'Linewidth',2)
set(gca, 'XLim', [1,10]);
ylabel('variance explained [%]')
xlabel('EOF #')

if  printFigs
    print(gcf,fullfile(figDir, 'varexplained_chl_NewEngland'), '-dpng', '-r300')
end

%% 4.3) look at EOF amplitude through time (i.e. PC scores)
score = cell(1,4);
for i=1:4
    score{i} = chl2D_an*V(:,i);
end
figure(5)
hold on
plot(0:length(score{1})-1, score{1},'b-','linewidth',2)
plot(0:length(score{2})-1, score{2},'r-','linewidth',2)
line([0, length(score{1})-1], [0, 0], 'Color', 'k');
set(gca, 'XLim', [0, length(score{1})-1], 'XTick', 0:6:length(score{1}));
legend('1','2','Location','SouthWest')
xlabel(['month since ' date_str{1}])
ylabel('Principal Component Score')

if  printFigs
    print(gcf, fullfile(figDir, 'EOFscores_chl_NewEngland'), '-dpng', '-r300')
end

%% do EOF reconstruction
EOF_reconstruction